from pyfiglet import Figlet
import requests
import json

def figlet(text, mode="small"):
    f = Figlet(font=mode)
    render = f.renderText(text)
    return render

def urban(query):
    try:
        urban = requests.get(f'https://api.urbandictionary.com/v0/define?term={query}')
        url = json.loads(urban.text)
    except Exception:
        return "Urban API returned invalid data... might be down or your IP is banned."

    if not url:
        return "I think the API broke..."

    if not len(url['list']):
        return "Couldn't find your search in the dictionary..."

    result = sorted(url['list'], reverse=True, key=lambda g: int(g["thumbs_up"]))[0]
    return result[0]


from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="NekoMimi",
    version="1.0.4",
    author="NekoMimi",
    author_email="mrcreaperwhantsadingdongtobedo@gmail.com",
    description="A handy collection of tools",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/NekoKitsune/NekoMimi",
    project_urls={
        "Bug Tracker": "https://github.com/NekoKitsune/NekoMimi/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=['NekoMimi'],
    scripts=['NekoMimi/NekoMimi.py','NekoMimi/__init__.py'],
    python_requires=">=3.6",
)
